@@ -1,4 +1,4 @@
-# Copyright (c) 2008 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2009 Riverbank Computing Limited <info@riverbankcomputing.com>
 # 
 # This file is part of PyQt.
 # 
@@ -44,9 +44,9 @@ _pkg_config = {
     'pyqt_mod_dir':      '/usr/local/lib/python2.5/site-packages/PyQt4',
     'pyqt_modules':      'QtCore QtGui QtNetwork QtOpenGL QtScript QtSql QtSvg QtTest QtXml QtAssistant QtDesigner',
     'pyqt_sip_dir':      '/usr/local/share/sip',
-    'pyqt_sip_flags':    '-x VendorID -t WS_X11 -x PyQt_NoPrintRangeBug -t Qt_4_4_1 -g',
-    'pyqt_version':      0x040404,
-    'pyqt_version_str':  '4.4.4',
+    'pyqt_sip_flags':    '-x VendorID -t WS_X11 -x PyQt_NoPrintRangeBug -t Qt_4_5_0 -x Py_v3 -g',
+    'pyqt_version':      0x040504,
+    'pyqt_version_str':  '4.5.4',
     'qt_data_dir':       '/usr/local/lib/qt4',
     'qt_dir':            '/usr/local/lib/qt4',
     'qt_edition':        'free',
@@ -54,7 +54,7 @@ _pkg_config = {
     'qt_inc_dir':        '/usr/local/include/X11/qt4',
     'qt_lib_dir':        '/usr/local/lib/qt4',
     'qt_threaded':       1,
-    'qt_version':        0x040501,
+    'qt_version':        0x040503,
     'qt_winconfig':      'shared'
 }
 
@@ -176,7 +176,7 @@ class QtCoreModuleMakefile(sipconfig.SIPModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore"]
 
         sipconfig.SIPModuleMakefile.__init__(self, *args, **kw)
@@ -188,7 +188,7 @@ class QtGuiModuleMakefile(QtCoreModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtGui"]
 
         QtCoreModuleMakefile.__init__(self, *args, **kw)
@@ -200,7 +200,7 @@ class QtHelpModuleMakefile(QtGuiModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtGui", "QtHelp"]
 
         QtGuiModuleMakefile.__init__(self, *args, **kw)
@@ -212,7 +212,7 @@ class QtNetworkModuleMakefile(QtCoreModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtNetwork"]
 
         QtCoreModuleMakefile.__init__(self, *args, **kw)
@@ -224,7 +224,7 @@ class QtAssistantModuleMakefile(QtNetworkModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtGui", "QtNetwork", "QtAssistant"]
 
         QtNetworkModuleMakefile.__init__(self, *args, **kw)
@@ -238,7 +238,7 @@ class QtOpenGLModuleMakefile(QtGuiModuleMakefile):
         """
         kw["opengl"] = 1
 
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtGui", "QtOpenGL"]
 
         QtGuiModuleMakefile.__init__(self, *args, **kw)
@@ -250,19 +250,31 @@ class QtScriptModuleMakefile(QtCoreModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtScript"]
 
         QtCoreModuleMakefile.__init__(self, *args, **kw)
 
 
+class QtScriptToolsModuleMakefile(QtScriptModuleMakefile):
+    """The Makefile class for modules that %Import QtScriptTools.
+    """
+    def __init__(self, *args, **kw):
+        """Initialise an instance of a module Makefile.
+        """
+        if "qt" not in kw:
+            kw["qt"] = ["QtCore", "QtGui", "QtScript", "QtScriptTools"]
+
+        QtScriptModuleMakefile.__init__(self, *args, **kw)
+
+
 class QtSqlModuleMakefile(QtGuiModuleMakefile):
     """The Makefile class for modules that %Import QtSql.
     """
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtGui", "QtSql"]
 
         QtGuiModuleMakefile.__init__(self, *args, **kw)
@@ -274,7 +286,7 @@ class QtSvgModuleMakefile(QtGuiModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtGui", "QtSvg"]
 
         QtGuiModuleMakefile.__init__(self, *args, **kw)
@@ -286,7 +298,7 @@ class QtTestModuleMakefile(QtGuiModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtGui", "QtTest"]
 
         QtGuiModuleMakefile.__init__(self, *args, **kw)
@@ -298,7 +310,7 @@ class QtWebKitModuleMakefile(QtNetworkModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtGui", "QtNetwork", "QtWebKit"]
 
         QtNetworkModuleMakefile.__init__(self, *args, **kw)
@@ -310,7 +322,7 @@ class QtXmlModuleMakefile(QtCoreModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtXml"]
 
         QtCoreModuleMakefile.__init__(self, *args, **kw)
@@ -322,7 +334,7 @@ class QtXmlPatternsModuleMakefile(QtCoreModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtXmlPatterns"]
 
         QtCoreModuleMakefile.__init__(self, *args, **kw)
@@ -334,7 +346,7 @@ class phononModuleMakefile(QtGuiModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtGui", "phonon"]
 
         QtGuiModuleMakefile.__init__(self, *args, **kw)
@@ -346,7 +358,7 @@ class QtDesignerModuleMakefile(QtGuiModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtGui", "QtDesigner"]
 
         QtGuiModuleMakefile.__init__(self, *args, **kw)
@@ -358,7 +370,7 @@ class QAxContainerModuleMakefile(QtGuiModuleMakefile):
     def __init__(self, *args, **kw):
         """Initialise an instance of a module Makefile.
         """
-        if not kw.has_key("qt"):
+        if "qt" not in kw:
             kw["qt"] = ["QtCore", "QtGui", "QAxContainer"]
 
         QtGuiModuleMakefile.__init__(self, *args, **kw)
